@@ -4,6 +4,7 @@ from pydantic.generics import GenericModel
 
 DataT = TypeVar('DataT')
 
+
 class Response(GenericModel, Generic[DataT]):
     data: DataT
 
@@ -11,5 +12,6 @@ class Response(GenericModel, Generic[DataT]):
     def __concrete_name__(cls: Type[Any], params: Tuple[Type[Any], ...]) -> str:
         return f'{params[0].__name__.title()}Response'
 
-print(Response[int](data=1))
-print(Response[str](data='a'))
+
+print(repr(Response[int](data=1)))
+print(repr(Response[str](data='a')))
