@@ -1,12 +1,16 @@
 import pickle
 from datetime import datetime
+from pathlib import Path
+
 from pydantic import BaseModel, ValidationError
 
+
 class User(BaseModel):
     id: int
     name = 'John Doe'
     signup_ts: datetime = None
 
+
 m = User.parse_obj({'id': 123, 'name': 'James'})
 print(m)
 
@@ -24,6 +28,15 @@ pickle_data = pickle.dumps({
     'name': 'James',
     'signup_ts': datetime(2017, 7, 14)
 })
-m = User.parse_raw(pickle_data, content_type='application/pickle',
-                   allow_pickle=True)
+m = User.parse_raw(
+    pickle_data, content_type='application/pickle', allow_pickle=True
+)
 print(m)
+
+path = Path('data.json')
+path.write_text('{"id": 123, "name": "James"}')
+m = User.parse_file(path)
+print(m)
+# ignore-below
+if path.exists():
+    path.unlink()
