@@ -1,8 +1,11 @@
 from __future__ import annotations
-from typing import List
+from typing import Any, List
 from pydantic import BaseModel
 
+
 class Model(BaseModel):
     a: List[int]
+    b: Any
 
-print(Model(a=('1', 2, 3)))
+
+print(Model(a=('1', 2, 3), b='ok'))
