@@ -1,14 +1,11 @@
 import sys
-from typing import Optional, Tuple
+from typing import Dict, ForwardRef, List, Optional, Tuple
 
 import pytest
 
 from pydantic import BaseModel, ConfigError, ValidationError
 
-skip_pre_37 = pytest.mark.skipif(sys.version_info < (3, 7), reason='testing >= 3.7 behaviour only')
 
-
-@skip_pre_37
 def test_postponed_annotations(create_module):
     module = create_module(
         # language=Python
@@ -24,7 +21,6 @@ class Model(BaseModel):
     assert m.dict() == {'a': 123}
 
 
-@skip_pre_37
 def test_postponed_annotations_optional(create_module):
     module = create_module(
         # language=Python
@@ -41,7 +37,6 @@ class Model(BaseModel):
     assert module.Model().dict() == {'a': None}
 
 
-@skip_pre_37
 def test_postponed_annotations_auto_update_forward_refs(create_module):
     module = create_module(
         # language=Python
@@ -71,8 +66,6 @@ class Bar(BaseModel):
 """
     )
 
-    from pydantic.typing import ForwardRef
-
     assert module.Foo.__fields__['a'].type_ == ForwardRef('Bar')
     assert module.Bar.__fields__['b'].type_ is module.Foo
 
@@ -86,8 +79,6 @@ def test_forward_ref_one_of_fields_not_defined(create_module):
             foo: 'Foo'
             bar: 'Bar'  # noqa: F821
 
-    from pydantic.typing import ForwardRef
-
     assert module.Foo.__fields__['bar'].type_ == ForwardRef('Bar')
     assert module.Foo.__fields__['foo'].type_ is module.Foo
 
@@ -95,10 +86,9 @@ def test_forward_ref_one_of_fields_not_defined(create_module):
 def test_basic_forward_ref(create_module):
     @create_module
     def module():
-        from typing import Optional
+        from typing import ForwardRef, Optional
 
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         class Foo(BaseModel):
             a: int
@@ -115,8 +105,9 @@ def test_basic_forward_ref(create_module):
 def test_self_forward_ref_module(create_module):
     @create_module
     def module():
+        from typing import ForwardRef
+
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         Foo = ForwardRef('Foo')
 
@@ -136,15 +127,12 @@ def test_self_forward_ref_collection(create_module):
         from typing import Dict, List
 
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
-
-        Foo = ForwardRef('Foo')
 
         class Foo(BaseModel):
             a: int = 123
-            b: Foo = None
-            c: List[Foo] = []
-            d: Dict[str, Foo] = {}
+            b: 'Foo' = None
+            c: 'List[Foo]' = []
+            d: 'Dict[str, Foo]' = {}
 
         Foo.update_forward_refs()
 
@@ -162,12 +150,21 @@ def test_self_forward_ref_collection(create_module):
         {'loc': ('c', 0, 'b'), 'msg': 'value is not a valid dict', 'type': 'type_error.dict'}
     ]
 
+    assert module.Foo.__fields__['a'].type_ is int
+    assert module.Foo.__fields__['b'].type_ is module.Foo
+    assert module.Foo.__fields__['b'].outer_type_ is module.Foo
+    assert module.Foo.__fields__['c'].type_ is module.Foo
+    assert module.Foo.__fields__['c'].outer_type_ == List[module.Foo]
+    assert module.Foo.__fields__['d'].type_ is module.Foo
+    assert module.Foo.__fields__['d'].outer_type_ == Dict[str, module.Foo]
+
 
 def test_self_forward_ref_local(create_module):
     @create_module
     def module():
+        from typing import ForwardRef
+
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         def main():
             Foo = ForwardRef('Foo')
@@ -187,8 +184,9 @@ def test_self_forward_ref_local(create_module):
 def test_missing_update_forward_refs(create_module):
     @create_module
     def module():
+        from typing import ForwardRef
+
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         Foo = ForwardRef('Foo')
 
@@ -215,7 +213,6 @@ def test_forward_ref_dataclass(create_module):
     assert m.url == 'http://example.com'
 
 
-@skip_pre_37
 def test_forward_ref_dataclass_with_future_annotations(create_module):
     module = create_module(
         # language=Python
@@ -236,10 +233,9 @@ class Dataclass:
 def test_forward_ref_sub_types(create_module):
     @create_module
     def module():
-        from typing import Union
+        from typing import ForwardRef, Union
 
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         class Leaf(BaseModel):
             a: str
@@ -265,10 +261,9 @@ def test_forward_ref_sub_types(create_module):
 def test_forward_ref_nested_sub_types(create_module):
     @create_module
     def module():
-        from typing import Tuple, Union
+        from typing import ForwardRef, Tuple, Union
 
         from pydantic import BaseModel
-        from pydantic.typing import ForwardRef
 
         class Leaf(BaseModel):
             a: str
@@ -330,7 +325,6 @@ def test_self_reference_json_schema(create_module):
     }
 
 
-@skip_pre_37
 def test_self_reference_json_schema_with_future_annotations(create_module):
     module = create_module(
         # language=Python
@@ -415,7 +409,6 @@ def test_circular_reference_json_schema(create_module):
     }
 
 
-@skip_pre_37
 def test_circular_reference_json_schema_with_future_annotations(create_module):
     module = create_module(
         # language=Python
@@ -468,12 +461,11 @@ Owner.update_forward_refs()
 def test_forward_ref_with_field(create_module):
     @create_module
     def module():
-        from typing import List
+        from typing import ForwardRef, List
 
         import pytest
 
         from pydantic import BaseModel, Field
-        from pydantic.typing import ForwardRef
 
         Foo = ForwardRef('Foo')
 
@@ -485,7 +477,6 @@ def test_forward_ref_with_field(create_module):
                 c: List[Foo] = Field(..., gt=0)
 
 
-@skip_pre_37
 def test_forward_ref_optional(create_module):
     module = create_module(
         # language=Python
@@ -531,7 +522,6 @@ def test_forward_ref_with_create_model(create_module):
         assert instance.sub.dict() == {'foo': 'bar'}
 
 
-@skip_pre_37
 def test_resolve_forward_ref_dataclass(create_module):
     module = create_module(
         # language=Python
@@ -593,7 +583,7 @@ def test_discriminated_union_forward_ref(create_module):
     assert module.Pet.schema() == {
         'title': 'Pet',
         'discriminator': {'propertyName': 'type', 'mapping': {'cat': '#/definitions/Cat', 'dog': '#/definitions/Dog'}},
-        'anyOf': [{'$ref': '#/definitions/Cat'}, {'$ref': '#/definitions/Dog'}],
+        'oneOf': [{'$ref': '#/definitions/Cat'}, {'$ref': '#/definitions/Dog'}],
         'definitions': {
             'Cat': {
                 'title': 'Cat',
@@ -611,7 +601,6 @@ def test_discriminated_union_forward_ref(create_module):
     }
 
 
-@skip_pre_37
 def test_class_var_as_string(create_module):
     module = create_module(
         # language=Python
@@ -628,7 +617,6 @@ class Model(BaseModel):
     assert module.Model.__class_vars__ == {'a'}
 
 
-@skip_pre_37
 def test_json_encoder_str(create_module):
     module = create_module(
         # language=Python
@@ -662,7 +650,6 @@ class Model(BaseModel):
     assert m.json(models_as_dict=False) == '{"foo_user": {"x": "user1"}, "user": "User(user2)"}'
 
 
-@skip_pre_37
 def test_json_encoder_forward_ref(create_module):
     module = create_module(
         # language=Python
